<?php

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('base');

///////////////////////////////////////////////////////////////////////////////
// D A T A
///////////////////////////////////////////////////////////////////////////////

// Grub codes
//
// The following is a mapping of grub language codes to glibc locales.

$grub_codes = array(
	'ca' => 'ca_ES',
	'da' => 'da_DK',
	'de' => 'de_DE',
	'de@hebrew' => 'de_DE',
	'de_CH' => 'de_CH',
	'en' => 'en_US',
	'en@arabic' => 'en_US',
	'en@cyrillic' => 'en_US',
	'en@greek' => 'en_US',
	'en@hebrew' => 'en_US',
	'en@piglatin' => 'en_US',
	'en@quot' => 'en_US',
	'es' => 'es_ES',
	'fi' => 'fi_FI',
	'fr' => 'fr_FR',
	'gl' => 'gl_ES',
	'hu' => 'hu_HU',
	'id' => 'id_ID',
	'it' => 'it_IT',
	'ja' => 'ja_JP',
	'lt' => 'lt_LT',
	'nl' => 'nl_NL',
	'pa' => 'pa_PK',
	'pl' => 'pl_PL',
	'pt_BR' => 'pt_BR',
	'ru' => 'ru_RU',
	'sl' => 'sl_SI',
	'sv' => 'sv_SE',
	'tr' => 'tr_TR',
	'uk' => 'uk_UA',
	'vi' => 'vi_VN',
	'zh_CN' => 'zh_CN',
	'zh_TW' => 'zh_TW',
);

// Locales
//
// /etc/locale.conf locales supported by ClearOS

$locales = array(
	'af_ZA' => array(
        'translation_code' => 'af',
        'description' => lang('language_code_af'),
        'native_description' => 'Afrikaans',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Africa/Johannesburg',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
	'ar_SA' => array(
        'translation_code' => 'ar',
        'description' => lang('language_code_ar'),
        'native_description' => 'العَرَبِيَّة',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Riyadh',
        'text_direction' => 'RTL',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
	'az_AZ' => array(
        'translation_code' => 'az',
        'description' => lang('language_code_az'),
        'native_description' => 'Azərbaycan dili',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
	'be_BY' => array(
        'translation_code' => 'be',
        'description' => lang('language_code_be'),
        'native_description' => 'беларуская мова',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
	'bg_BG' => array(
        'translation_code' => 'bg',
        'description' => lang('language_code_bg'),
        'native_description' => 'български',
        'default_keyboard' => 'bg',
        'default_time_zone' => 'Europe/Sofia',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
	'bn_BD' => array(
        'translation_code' => 'bn',
        'description' => lang('language_code_bn'),
        'native_description' => 'বাংলা',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Dhaka',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
	'bs_BA' => array(
        'translation_code' => 'bs',
        'description' => lang('language_code_bs'),
        'native_description' => 'bosanski',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'ca_ES' => array(
        'translation_code' => 'ca',
        'description' => lang('language_code_ca'),
        'native_description' => 'Català',
        'default_keyboard' => 'es',
        'default_time_zone' => 'Europe/Madrid',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'cs_CZ' => array(
        'translation_code' => 'cs',
        'description' => lang('language_code_cs'),
        'native_description' => 'čeština',
        'default_keyboard' => 'cz-lat2',
        'default_time_zone' => 'Europe/Prague',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'cy_GB' => array(
        'translation_code' => 'cy',
        'description' => lang('language_code_cy'),
        'native_description' => 'Cymraeg',
        'default_keyboard' => 'uk',
        'default_time_zone' => 'Europe/London',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'da_DK' => array(
        'translation_code' => 'da',
        'description' => lang('language_code_da'),
        'native_description' => 'Dansk',
        'default_keyboard' => 'dk',
        'default_time_zone' => 'Europe/Copenhagen',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'de_DE' => array(
        'translation_code' => 'de',
        'description' => lang('language_code_de'),
        'native_description' => 'Deutsch',
        'default_keyboard' => 'de-latin1-nodeadkeys',
        'default_time_zone' => 'Europe/Berlin',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'el_GR' => array(
        'translation_code' => 'el',
        'description' => lang('language_code_el'),
        'native_description' => 'Ελληνικά',
        'default_keyboard' => 'gr',
        'default_time_zone' => 'Europe/Athens',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'iso07u-16'
    ),
    'en_US' => array(
        'translation_code' => 'en',
        'description' => lang('language_code_en'),
        'native_description' => 'English',
        'default_keyboard' => 'us',
        'default_time_zone' => 'America/New_York',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'eo' => array(
        'translation_code' => 'eo',
        'description' => lang('language_code_eo'),
        'native_description' => 'Esperanto',
        'default_keyboard' => 'us',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'es_ES' => array(
        'translation_code' => 'es',
        'description' => lang('language_code_es'),
        'native_description' => 'Español',
        'default_keyboard' => 'es',
        'default_time_zone' => 'Europe/Madrid',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'et_EE' => array(
        'translation_code' => 'et',
        'description' => lang('language_code_et'),
        'native_description' => 'eesti keel',
        'default_keyboard' => 'et',
        'default_time_zone' => 'Europe/Tallinn',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'eu_ES' => array(
        'translation_code' => 'eu',
        'description' => lang('language_code_eu'),
        'native_description' => 'Euskara',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'fa_IR' => array(
        'translation_code' => 'fa',
        'description' => lang('language_code_fa'),
        'native_description' => 'پارسی',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Tehran',
        'text_direction' => 'RTL',
        'encoding' => 'UTF-8'
    ),
    'fi_FI' => array(
        'translation_code' => 'fi',
        'description' => lang('language_code_fi'),
        'native_description' => 'Suomi',
        'default_keyboard' => 'fi',
        'default_time_zone' => 'Europe/Helsinki',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'fr_FR' => array(
        'translation_code' => 'fr',
        'description' => lang('language_code_fr'),
        'native_description' => 'Français',
        'default_keyboard' => 'fr-latin1',
        'default_time_zone' => 'Europe/Paris',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ga_IE' => array(
        'translation_code' => 'ga',
        'description' => lang('language_code_ga'),
        'native_description' => 'Gaeilge',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'gl_ES' => array(
        'translation_code' => 'gl',
        'description' => lang('language_code_gl'),
        'native_description' => 'galego',
        'default_keyboard' => '',
        'default_time_zone' => 'Europe/Madrid',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'gu_IN' => array(
        'translation_code' => 'gu',
        'description' => lang('language_code_gu'),
        'native_description' => 'ગુજરાતી',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ha_NG' => array(
        'translation_code' => 'ha',
        'description' => lang('language_code_ha'),
        'native_description' => 'Harshen Hausa',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'hi_IN' => array(
        'translation_code' => 'hi',
        'description' => lang('language_code_hi'),
        'native_description' => 'हिन्दी',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'hr_HR' => array(
        'translation_code' => 'hr',
        'description' => lang('language_code_hr'),
        'native_description' => 'Hrvatski',
        'default_keyboard' => 'croat',
        'default_time_zone' => 'Europe/Zagreb',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ht_HT' => array(
        'translation_code' => 'ht',
        'description' => lang('language_code_ht'),
        'native_description' => 'Kreyòl ayisyen',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => ''
    ),
    'hu_HU' => array(
        'translation_code' => 'hu',
        'description' => lang('language_code_hu'),
        'native_description' => 'magyar',
        'default_keyboard' => 'hu',
        'default_time_zone' => 'Europe/Budapest',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'hy_AM' => array(
        'translation_code' => 'hy',
        'description' => lang('language_code_hy'),
        'native_description' => 'Հայերեն',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'id_ID' => array(
        'translation_code' => 'id',
        'description' => lang('language_code_id'),
        'native_description' => 'Bahasa Indonesia',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Jakarta',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ig_NG' => array(
        'translation_code' => 'ig',
        'description' => lang('language_code_ig'),
        'native_description' => 'igbo',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'is_IS' => array(
        'translation_code' => 'is',
        'description' => lang('language_code_is'),
        'native_description' => 'Íslenska',
        'default_keyboard' => 'is-latin1',
        'default_time_zone' => 'Atlantic/Reykjavik',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'it_IT' => array(
        'translation_code' => 'it',
        'description' => lang('language_code_it'),
        'native_description' => 'Italiano',
        'default_keyboard' => 'it',
        'default_time_zone' => 'Europe/Rome',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ja_JP' => array(
        'translation_code' => 'ja',
        'description' => lang('language_code_ja'),
        'native_description' => '日本語',
        'default_keyboard' => 'jp106',
        'default_time_zone' => 'Asia/Tokyo',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ka_GE' => array(
        'translation_code' => 'ka',
        'description' => lang('language_code_ka'),
        'native_description' => 'ქართული',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'km_KH' => array(
        'translation_code' => 'km',
        'description' => lang('language_code_km'),
        'native_description' => 'ភាសាខ្មែរ',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'kk_KZ' => array(
        'translation_code' => 'kk',
        'description' => lang('language_code_kk'),
        'native_description' => 'Қазақ тілі',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'kn_IN' => array(
        'translation_code' => 'kn',
        'description' => lang('language_code_kn'),
        'native_description' => 'ಕನ್ನಡ',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ko_KR' => array(
        'translation_code' => 'ko',
        'description' => lang('language_code_ko'),
        'native_description' => '한국어',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Seoul',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'lo_LA' => array(
        'translation_code' => 'lo',
        'description' => lang('language_code_lo'),
        'native_description' => 'ພາສາລາວ',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'lt_LT' => array(
        'translation_code' => 'lt',
        'description' => lang('language_code_lt'),
        'native_description' => 'lietuvių kalba',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'lv_LV' => array(
        'translation_code' => 'lv',
        'description' => lang('language_code_lv'),
        'native_description' => 'latviešu valoda',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'mg_MG' => array(
        'translation_code' => 'mg',
        'description' => lang('language_code_mg'),
        'native_description' => 'Fiteny Malagasy',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'mi_NZ' => array(
        'translation_code' => 'mi',
        'description' => lang('language_code_mi'),
        'native_description' => 'Te Reo Māori',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'mk_MK' => array(
        'translation_code' => 'mk',
        'description' => lang('language_code_mk'),
        'native_description' => 'македонски',
        'default_keyboard' => 'mk',
        'default_time_zone' => 'Europe/Skopje',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ml_IN' => array(
        'translation_code' => 'ml',
        'description' => lang('language_code_ml'),
        'native_description' => 'മലയാളം',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'mn_MN' => array(
        'translation_code' => 'mn',
        'description' => lang('language_code_mn'),
        'native_description' => 'Монгол',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'mr_IN' => array(
        'translation_code' => 'mr',
        'description' => lang('language_code_mr'),
        'native_description' => 'मराठी',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ms_MY' => array(
        'translation_code' => 'ms',
        'description' => lang('language_code_ms'),
        'native_description' => 'Bahasa melayu',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kuala_Lumpur',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'mt_MT' => array(
        'translation_code' => 'mt',
        'description' => lang('language_code_mt'),
        'native_description' => 'Malti',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'my_MM' => array(
        'translation_code' => 'my',
        'description' => lang('language_code_my'),
        'native_description' => 'မြန်မာစာ',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Rangoon',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'nb_NO' => array(
        'translation_code' => 'no',
        'description' => lang('language_code_no'),
        'native_description' => 'Norsk',
        'default_keyboard' => 'no',
        'default_time_zone' => 'Europe/Oslo',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ne_NP' => array(
        'translation_code' => 'ne',
        'description' => lang('language_code_ne'),
        'native_description' => 'नेपाली',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'nl_NL' => array(
        'translation_code' => 'nl',
        'description' => lang('language_code_nl'),
        'native_description' => 'Nederlands',
        'default_keyboard' => 'nl',
        'default_time_zone' => 'Europe/Amsterdam',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'pa_IN' => array(
        'translation_code' => 'pa',
        'description' => lang('language_code_pa'),
        'native_description' => 'ਪੰਜਾਬੀ',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'pl_PL' => array(
        'translation_code' => 'pl',
        'description' => lang('language_code_pl'),
        'native_description' => 'Polski',
        'default_keyboard' => 'pl2',
        'default_time_zone' => 'Europe/Warsaw',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'pt_PT' => array(
        'translation_code' => 'pt',
        'description' => lang('language_code_pt'),
        'native_description' => 'Português',
        'default_keyboard' => 'pt-latin1',
        'default_time_zone' => 'Europe/Lisbon',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ro_RO' => array(
        'translation_code' => 'ro',
        'description' => lang('language_code_ro'),
        'native_description' => 'Română',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Europe/Bucharest',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ru_RU' => array(
        'translation_code' => 'ru',
        'description' => lang('language_code_ru'),
        'native_description' => 'Русский',
        'default_keyboard' => 'ru',
        'default_time_zone' => 'Europe/Moscow',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'si_LK' => array(
        'translation_code' => 'si',
        'description' => lang('language_code_si'),
        'native_description' => 'සිංහල',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Colombo',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'sk_SK' => array(
        'translation_code' => 'sk',
        'description' => lang('language_code_sk'),
        'native_description' => 'Slovenčina',
        'default_keyboard' => 'sk-qwerty',
        'default_time_zone' => 'Europe/Bratislava',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'sl_SI' => array(
        'translation_code' => 'sl',
        'description' => lang('language_code_sl'),
        'native_description' => 'Slovaščina',
        'default_keyboard' => 'slovene',
        'default_time_zone' => 'Europe/Ljubljana',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'so_SO' => array(
        'translation_code' => 'so',
        'description' => lang('language_code_so'),
        'native_description' => 'af Soomaali',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'sq_AL' => array(
        'translation_code' => 'sq',
        'description' => lang('language_code_sq'),
        'native_description' => 'Shqip',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'sr_RS' => array(
        'translation_code' => 'sr',
        'description' => lang('language_code_sr'),
        'native_description' => 'српски',
        'default_keyboard' => 'sr-cy',
        'default_time_zone' => 'Europe/Belgrade',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'st_ZA' => array(
        'translation_code' => 'st',
        'description' => lang('language_code_st'),
        'native_description' => 'seSotho',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'sv_SE' => array(
        'translation_code' => 'sv',
        'description' => lang('language_code_sv'),
        'native_description' => 'Svenska',
        'default_keyboard' => 'sv-latin1',
        'default_time_zone' => 'Europe/Stockholm',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'sw_TZ' => array(
        'translation_code' => 'sw',
        'description' => lang('language_code_sw'),
        'native_description' => 'Kiswahili',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'ta_IN' => array(
        'translation_code' => 'ta',
        'description' => lang('language_code_ta'),
        'native_description' => 'தமிழ்',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'te_IN' => array(
        'translation_code' => 'te',
        'description' => lang('language_code_te'),
        'native_description' => 'తెలుగు',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Kolkata',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'tg_TJ' => array(
        'translation_code' => 'tg',
        'description' => lang('language_code_tg'),
        'native_description' => 'тоҷики',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'th_TH' => array(
        'translation_code' => 'th',
        'description' => lang('language_code_th'),
        'native_description' => 'ภาษาไทย',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'tl_PH' => array(
        'translation_code' => 'tl',
        'description' => lang('language_code_tl'),
        'native_description' => 'Tagalog',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Manila',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'tr_TR' => array(
        'translation_code' => 'tr',
        'description' => lang('language_code_tr'),
        'native_description' => 'Türkçe',
        'default_keyboard' => 'trq',
        'default_time_zone' => 'Europe/Istanbul',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'uk_UA' => array(
        'translation_code' => 'uk',
        'description' => lang('language_code_uk'),
        'native_description' => 'Українська',
        'default_keyboard' => 'ua-utf',
        'default_time_zone' => 'Europe/Kiev',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'ur_PK' => array(
        'translation_code' => 'ur',
        'description' => lang('language_code_ur'),
        'native_description' => 'اردو',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'RTL',
        'encoding' => 'UTF-8',
    ),
    'uz_UZ' => array(
        'translation_code' => 'uz',
        'description' => lang('language_code_uz'),
        'native_description' => 'oʻzbek tili',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'vi_VN' => array(
        'translation_code' => 'vi',
        'description' => lang('language_code_vi'),
        'native_description' => 'tiếng việt',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Saigon',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
    'yi_US' => array(
        'translation_code' => 'yi',
        'description' => lang('language_code_yi'),
        'native_description' => 'ײִדיש',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'RTL',
        'encoding' => 'UTF-8',
    ),
    'yo_NG' => array(
        'translation_code' => 'yo',
        'description' => lang('language_code_yo'),
        'native_description' => 'Yorùbá',
        'default_keyboard' => '',
        'default_time_zone' => '',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
    ),
    'zh_CN' => array(
        'translation_code' => 'zh',
        'description' => lang('language_code_zh'),
        'native_description' => '中文',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Asia/Shanghai',
        'text_direction' => 'LTR',
        'encoding' => 'GB2312',
    ),
    'zu_ZA' => array(
        'translation_code' => 'zu',
        'description' => lang('language_code_zu'),
        'native_description' => 'isiZulu',
        'default_keyboard' => 'us',
        'default_time_zone' => 'Africa/Johannesburg',
        'text_direction' => 'LTR',
        'encoding' => 'UTF-8',
        'font' => 'latarcyrheb-sun16'
    ),
);
